@@ -1112,7 +1112,7 @@ class GATConv(Conv):
         x, a = inputs
 
         mode = ops.autodetect_mode(x, a)
-        if mode == modes.SINGLE and K.is_sparse(a):
+        if mode == ops.SINGLE and K.is_sparse(a):
             output, attn_coef = self._call_single(x, a)
         else:
             if K.is_sparse(a):
