@@ -1,11 +1,12 @@
 import numpy as np
-
 from notekeras.activations import gelu
 from notekeras.backend import keras
 from notekeras.component.transformer import EncoderList
-from notekeras.component.transformer import get_custom_objects as get_encoder_custom_objects
-from notekeras.layers.embedding import PositionEmbedding, get_embedding
-from notekeras.layers.embedding import TokenEmbedding, EmbeddingSimilarity, TaskEmbedding
+from notekeras.component.transformer import \
+    get_custom_objects as get_encoder_custom_objects
+from notekeras.layers.embedding import (EmbeddingSimilarity, PositionEmbedding,
+                                        TaskEmbedding, TokenEmbedding,
+                                        get_embedding)
 from notekeras.layers.extract import Extract
 from notekeras.layers.inputs import get_inputs
 from notekeras.layers.masked import Masked
@@ -45,8 +46,7 @@ class BertModel(keras.models.Model):
                  use_task_embed=False,
                  task_num=10,
                  use_adapter=False,
-                 adapter_units=None
-                 , **kwargs):
+                 adapter_units=None, **kwargs):
         """Get BERT model.
 
            See: https://arxiv.org/pdf/1810.04805.pdf
@@ -98,7 +98,8 @@ class BertModel(keras.models.Model):
         self.input_layer = self.output_layer = None
         self._build()
 
-        super(BertModel, self).__init__(inputs=self.input_layer, outputs=self.output_layer, **kwargs)
+        super(BertModel, self).__init__(
+            inputs=self.input_layer, outputs=self.output_layer, **kwargs)
 
         for layer in self.layers:
             if type(type) == keras.layers.Layer:
@@ -138,10 +139,12 @@ class BertModel(keras.models.Model):
                                         )([embed_layer, task_input])
             inputs = inputs[:2] + [task_input, inputs[-1]]
         if self.dropout_rate > 0.0:
-            dropout_layer = keras.layers.Dropout(rate=self.dropout_rate, name='Embedding-Dropout', )(embed_layer)
+            dropout_layer = keras.layers.Dropout(
+                rate=self.dropout_rate, name='Embedding-Dropout', )(embed_layer)
         else:
             dropout_layer = embed_layer
-        embed_layer = LayerNormalization(trainable=self.trainable, name='Embedding-Norm', )(dropout_layer)
+        embed_layer = LayerNormalization(
+            trainable=self.trainable, name='Embedding-Norm', )(dropout_layer)
 
         transformed = EncoderList(encoder_num=self.transformer_num,
                                   head_num=self.head_num,
@@ -158,14 +161,18 @@ class BertModel(keras.models.Model):
                                                  activation=self.feed_forward_activation,
                                                  name='MLM-Dense',
                                                  )(transformed)
-            mlm_norm_layer = LayerNormalization(name='MLM-Norm')(mlm_dense_layer)
-            mlm_pred_layer = EmbeddingSimilarity(name='MLM-Sim')([mlm_norm_layer, embed_weights])
-            masked_layer = Masked(name='MLM')([mlm_pred_layer, inputs[-1]])
+            mlm_norm_layer = LayerNormalization(
+                name='MLM-Norm')(mlm_dense_layer)
+            mlm_pred_layer = EmbeddingSimilarity(
+                name='MLM-Sim')([mlm_norm_layer, embed_weights])
+            masked_layer = Masked(name='MLM')(mlm_pred_layer, inputs[-1])
             extract_layer = Extract(index=0, name='Extract')(transformed)
             nsp_dense_layer = keras.layers.Dense(units=self.embed_dim, activation='tanh', name='NSP-Dense', )(
                 extract_layer)
-            nsp_pred_layer = keras.layers.Dense(units=2, activation='softmax', name='NSP', )(nsp_dense_layer)
-            model = keras.models.Model(inputs=inputs, outputs=[masked_layer, nsp_pred_layer])
+            nsp_pred_layer = keras.layers.Dense(
+                units=2, activation='softmax', name='NSP', )(nsp_dense_layer)
+            model = keras.models.Model(inputs=inputs, outputs=[
+                                       masked_layer, nsp_pred_layer])
 
             self.input_layer = inputs
             self.output_layer = [masked_layer, nsp_pred_layer]
@@ -189,17 +196,21 @@ class BertModel(keras.models.Model):
             layer.trainable = self._trainable(layer)
 
         if isinstance(self.output_layer_num, int):
-            self.output_layer_num = min(self.output_layer_num, self.transformer_num)
-            self.output_layer_num = [-i for i in range(1, self.output_layer_num + 1)]
+            self.output_layer_num = min(
+                self.output_layer_num, self.transformer_num)
+            self.output_layer_num = [
+                -i for i in range(1, self.output_layer_num + 1)]
         outputs = []
         for layer_index in self.output_layer_num:
             if layer_index < 0:
                 layer_index = self.transformer_num + layer_index
             layer_index += 1
-            layer = self.get_layer(name='Encoder-{}-FeedForward-Norm'.format(layer_index))
+            layer = self.get_layer(
+                name='Encoder-{}-FeedForward-Norm'.format(layer_index))
             outputs.append(layer.output)
         if len(outputs) > 1:
-            transformed = keras.layers.Concatenate(name='Encoder-Output')(list(reversed(outputs)))
+            transformed = keras.layers.Concatenate(
+                name='Encoder-Output')(list(reversed(outputs)))
         else:
             transformed = outputs[0]
         return self.inputs, transformed
@@ -218,7 +229,8 @@ class BertModel(keras.models.Model):
                                  warmup_steps=warmup_steps,
                                  learning_rate=learning_rate,
                                  weight_decay=weight_decay,
-                                 weight_decay_pattern=['embeddings', 'kernel', 'W1', 'W2', 'Wk', 'Wq', 'Wv', 'Wo'],
+                                 weight_decay_pattern=[
+                                     'embeddings', 'kernel', 'W1', 'W2', 'Wk', 'Wq', 'Wv', 'Wo'],
                                  ),
             loss=keras.losses.sparse_categorical_crossentropy,
         )
@@ -305,10 +317,12 @@ def get_model(token_num,
                                     )([embed_layer, task_input])
         inputs = inputs[:2] + [task_input, inputs[-1]]
     if dropout_rate > 0.0:
-        dropout_layer = keras.layers.Dropout(rate=dropout_rate, name='Embedding-Dropout', )(embed_layer)
+        dropout_layer = keras.layers.Dropout(
+            rate=dropout_rate, name='Embedding-Dropout', )(embed_layer)
     else:
         dropout_layer = embed_layer
-    embed_layer = LayerNormalization(trainable=trainable, name='Embedding-Norm', )(dropout_layer)
+    embed_layer = LayerNormalization(
+        trainable=trainable, name='Embedding-Norm', )(dropout_layer)
 
     transformed = EncoderList(encoder_num=transformer_num,
                               head_num=head_num,
@@ -327,12 +341,16 @@ def get_model(token_num,
                                              name='MLM-Dense',
                                              )(transformed)
         mlm_norm_layer = LayerNormalization(name='MLM-Norm')(mlm_dense_layer)
-        mlm_pred_layer = EmbeddingSimilarity(name='MLM-Sim')([mlm_norm_layer, embed_weights])
+        mlm_pred_layer = EmbeddingSimilarity(
+            name='MLM-Sim')([mlm_norm_layer, embed_weights])
         masked_layer = Masked(name='MLM')([mlm_pred_layer, inputs[-1]])
         extract_layer = Extract(index=0, name='Extract')(transformed)
-        nsp_dense_layer = keras.layers.Dense(units=embed_dim, activation='tanh', name='NSP-Dense', )(extract_layer)
-        nsp_pred_layer = keras.layers.Dense(units=2, activation='softmax', name='NSP', )(nsp_dense_layer)
-        model = keras.models.Model(inputs=inputs, outputs=[masked_layer, nsp_pred_layer])
+        nsp_dense_layer = keras.layers.Dense(
+            units=embed_dim, activation='tanh', name='NSP-Dense', )(extract_layer)
+        nsp_pred_layer = keras.layers.Dense(
+            units=2, activation='softmax', name='NSP', )(nsp_dense_layer)
+        model = keras.models.Model(inputs=inputs, outputs=[
+                                   masked_layer, nsp_pred_layer])
         for layer in model.layers:
             layer.trainable = _trainable(layer)
         return model
@@ -352,10 +370,12 @@ def get_model(token_num,
             if layer_index < 0:
                 layer_index = transformer_num + layer_index
             layer_index += 1
-            layer = model.get_layer(name='Encoder-{}-FeedForward-Norm'.format(layer_index))
+            layer = model.get_layer(
+                name='Encoder-{}-FeedForward-Norm'.format(layer_index))
             outputs.append(layer.output)
         if len(outputs) > 1:
-            transformed = keras.layers.Concatenate(name='Encoder-Output')(list(reversed(outputs)))
+            transformed = keras.layers.Concatenate(
+                name='Encoder-Output')(list(reversed(outputs)))
         else:
             transformed = outputs[0]
         return inputs, transformed
@@ -457,7 +477,8 @@ def gen_batch_inputs(sentence_pairs,
     nsp_outputs = np.zeros((batch_size,))
     mapping = {}
     if swap_sentence_rate > 0.0:
-        indices = [index for index in range(batch_size) if np.random.random() < swap_sentence_rate]
+        indices = [index for index in range(
+            batch_size) if np.random.random() < swap_sentence_rate]
         mapped = indices[:]
         np.random.shuffle(mapped)
         for i in range(len(mapped)):
@@ -468,8 +489,10 @@ def gen_batch_inputs(sentence_pairs,
     token_inputs, segment_inputs, masked_inputs = [], [], []
     mlm_outputs = []
     for i in range(batch_size):
-        first, second = sentence_pairs[i][0], sentence_pairs[mapping.get(i, i)][1]
-        segment_inputs.append(([0] * (len(first) + 2) + [1] * (seq_len - (len(first) + 2)))[:seq_len])
+        first, second = sentence_pairs[i][0], sentence_pairs[mapping.get(
+            i, i)][1]
+        segment_inputs.append(
+            ([0] * (len(first) + 2) + [1] * (seq_len - (len(first) + 2)))[:seq_len])
         tokens = [TOKEN_CLS] + first + [TOKEN_SEP] + second + [TOKEN_SEP]
         tokens = tokens[:seq_len]
         tokens += [TOKEN_PAD] * (seq_len - len(tokens))
@@ -485,7 +508,8 @@ def gen_batch_inputs(sentence_pairs,
                     token_input.append(token_dict[TOKEN_MASK])
                 elif r < mask_mask_rate + mask_random_rate:
                     while True:
-                        token = token_list[np.random.randint(0, len(token_list))]
+                        token = token_list[np.random.randint(
+                            0, len(token_list))]
                         if token not in base_dict:
                             token_input.append(token_dict[token])
                             break
@@ -499,6 +523,8 @@ def gen_batch_inputs(sentence_pairs,
         token_inputs.append(token_input)
         masked_inputs.append(masked_input)
         mlm_outputs.append(mlm_output)
-    inputs = [np.asarray(x) for x in [token_inputs, segment_inputs, masked_inputs]]
-    outputs = [np.asarray(np.expand_dims(x, axis=-1)) for x in [mlm_outputs, nsp_outputs]]
+    inputs = [np.asarray(x)
+              for x in [token_inputs, segment_inputs, masked_inputs]]
+    outputs = [np.asarray(np.expand_dims(x, axis=-1))
+               for x in [mlm_outputs, nsp_outputs]]
     return inputs, outputs
